@@ -2,14 +2,26 @@ import abc
 import contextlib
 import logging
 
+from pydantic_settings import BaseSettings, SettingsConfigDict
+
 from arrlio.models import TaskInstance, TaskResult
 
 logger = logging.getLogger("arrlio.plugins.base")
 
 
+class Config(BaseSettings):
+    model_config = SettingsConfigDict()
+
+
 class Plugin(abc.ABC):
-    def __init__(self, app):
+    # pylint: disable=unused-argument
+
+    def __init__(self, app, config: Config):
         self.app = app
+        self.config = config
+
+    def __str__(self):
+        return f"Plugin[{self.name}]"
 
     @property
     @abc.abstractmethod
@@ -17,14 +29,13 @@ class Plugin(abc.ABC):
         pass
 
     async def on_init(self):
-        logger.info("Plugin[%s] initialization done", self.name)
+        pass
 
     async def on_close(self):
         pass
 
     @contextlib.asynccontextmanager
     def task_context(self, task_instance: TaskInstance):
-        # pylint: disable=unused-argument
         yield
 
     async def on_task_send(self, task_instance: TaskInstance) -> None:
@@ -33,5 +44,8 @@ class Plugin(abc.ABC):
     async def on_task_received(self, task_instance: TaskInstance) -> None:
         pass
 
+    async def on_task_result(self, task_instance: TaskInstance, task_result: TaskResult) -> None:
+        pass
+
     async def on_task_done(self, task_instance: TaskInstance, task_result: TaskResult) -> None:
         pass
