@@ -1,12 +1,19 @@
 from typing import Any
 
 from arrlio.models import Event, TaskInstance, TaskResult
-from arrlio.serializers.base import Serializer
+from arrlio.serializers import base
 
 
-class Serializer(Serializer):  # pylint: disable=function-redefined
-    def __str__(self):
-        return "nop.Serializer"
+class Config(base.Config):
+    pass
+
+
+class Serializer(base.Serializer):
+    def dumps(self, data: Any, **kwds) -> Any:
+        return data
+
+    def loads(self, data: Any) -> Any:
+        return data
 
     def dumps_task_instance(self, task_instance: TaskInstance, **kwds) -> TaskInstance:
         return task_instance
@@ -14,7 +21,7 @@ class Serializer(Serializer):  # pylint: disable=function-redefined
     def loads_task_instance(self, data: TaskInstance) -> TaskInstance:
         return data
 
-    def dumps_task_result(self, task_instance: TaskInstance, task_result: TaskResult, **kwds) -> TaskResult:
+    def dumps_task_result(self, task_result: TaskResult, task_instance: TaskInstance = None, **kwds) -> TaskResult:
         return task_result
 
     def loads_task_result(self, data: TaskResult) -> TaskResult:
@@ -25,9 +32,3 @@ class Serializer(Serializer):  # pylint: disable=function-redefined
 
     def loads_event(self, data: Event) -> Event:
         return data
-
-    def dumps(self, data: Any, **kwds) -> Any:
-        return data
-
-    def loads(self, data: Any) -> Any:
-        return data
